==> zio-aws-macie2_2.12-5.17.197.1-sources.jar: zio/aws/macie2/model/DisableOrganizationAdminAccountRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DisableOrganizationAdminAccountRequest(
    adminAccountId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest = {
    import DisableOrganizationAdminAccountRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
      .builder()
      .adminAccountId(adminAccountId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly =
    zio.aws.macie2.model.DisableOrganizationAdminAccountRequest
      .wrap(buildAwsValue())
}
object DisableOrganizationAdminAccountRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.DisableOrganizationAdminAccountRequest =
      zio.aws.macie2.model
        .DisableOrganizationAdminAccountRequest(adminAccountId)
    def adminAccountId: __string
    def getAdminAccountId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(adminAccountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ) extends zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly {
    override val adminAccountId: __string = impl.adminAccountId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ): zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_2.13-5.17.122.1-sources.jar: zio/aws/macie2/model/DisableOrganizationAdminAccountRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class DisableOrganizationAdminAccountRequest(
    adminAccountId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest = {
    import DisableOrganizationAdminAccountRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
      .builder()
      .adminAccountId(__string.unwrap(adminAccountId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly =
    zio.aws.macie2.model.DisableOrganizationAdminAccountRequest
      .wrap(buildAwsValue())
}
object DisableOrganizationAdminAccountRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.macie2.model.DisableOrganizationAdminAccountRequest =
      zio.aws.macie2.model
        .DisableOrganizationAdminAccountRequest(adminAccountId)
    def adminAccountId: __string
    def getAdminAccountId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(adminAccountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ) extends zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly {
    override val adminAccountId: __string =
      zio.aws.macie2.model.primitives.__string(impl.adminAccountId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DisableOrganizationAdminAccountRequest
  ): zio.aws.macie2.model.DisableOrganizationAdminAccountRequest.ReadOnly =
    new Wrapper(impl)
}
